ButcherTableau

Trait ButcherTableau 

pub trait ButcherTableau {
    const STAGES: usize;
    const ORDER: Scalar;
    const A: &'static [&'static [Scalar]];
    const C: &'static [Scalar];
    const B: &'static [Scalar];
    const FSAL: bool = false;
}
Butcher tableau for an explicit Runge–Kutta method.

Required Associated Constants

const STAGES: usize

Number of stages, equal to the number of stored slopes.

const ORDER: Scalar

Order of the propagating solution; the exponent for adaptive time steps.

const A: &'static [&'static [Scalar]]

Stage-coupling coefficients, A[i].len() == i.

const C: &'static [Scalar]

Stage abscissae, C[0] == 0.

const B: &'static [Scalar]

Propagating weights.

Provided Associated Constants

const FSAL: bool = false

Whether the last stage of a step is the first stage of the next.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ButcherTableau for conspire::math::integrate::BogackiShampineTableau

Source

const STAGES: usize = 4

Source

const ORDER: Scalar = 3.0

Source

const A: &'static [&'static [Scalar]]

Source

const C: &'static [Scalar]

Source

const B: &'static [Scalar]

Source

const FSAL: bool = true

Source

impl ButcherTableau for conspire::math::integrate::DormandPrinceTableau

Source

const STAGES: usize = 7

Source

const ORDER: Scalar = 5.0

Source

const A: &'static [&'static [Scalar]]

Source

const C: &'static [Scalar]

Source

const B: &'static [Scalar]

Source

const FSAL: bool = true

Source

impl ButcherTableau for conspire::math::integrate::Verner8Tableau

Source

const STAGES: usize = 13

Source

const ORDER: Scalar = 8.0

Source

const A: &'static [&'static [Scalar]]

Source

const C: &'static [Scalar]

Source

const B: &'static [Scalar]

Source

impl ButcherTableau for conspire::math::integrate::Verner9Tableau

Source

const STAGES: usize = 16

Source

const ORDER: Scalar = 9.0

Source

const A: &'static [&'static [Scalar]]

Source

const C: &'static [Scalar]

Source

const B: &'static [Scalar]