ExplicitDaeSecondOrderMinimize

Trait ExplicitDaeSecondOrderMinimize 

pub trait ExplicitDaeSecondOrderMinimize<F, J, H, Y, Z, U, V, W, T = Time>
where Y: Differentiate<T> + Tensor, Z: Tensor, U: TensorVec<Item = Y>, V: TensorVec<Item = Z>, W: TensorVec<Item = Derivative<Y, T>>,
{ // Required method fn integrate( &self, evolution: impl FnMut(Quantity<T>, &Y, &Z) -> Result<Derivative<Y, T>, String>, function: impl FnMut(Quantity<T>, &Y, &Z) -> Result<F, String>, jacobian: impl FnMut(Quantity<T>, &Y, &Z) -> Result<J, String>, hessian: impl FnMut(Quantity<T>, &Y, &Z) -> Result<H, String>, solver: impl SecondOrderOptimization<F, J, H, Z>, time: &[Quantity<T>], initial_condition: (Y, Z), equality_constraint: impl FnMut(Quantity<T>) -> EqualityConstraint, sparse: Option<SparseSolver>, ) -> Result<(Times<T>, U, W, V), IntegrationError>; }
Integrators for explicit differential-algebraic equations using second-order minimization.

Required Methods

fn integrate( &self, evolution: impl FnMut(Quantity<T>, &Y, &Z) -> Result<Derivative<Y, T>, String>, function: impl FnMut(Quantity<T>, &Y, &Z) -> Result<F, String>, jacobian: impl FnMut(Quantity<T>, &Y, &Z) -> Result<J, String>, hessian: impl FnMut(Quantity<T>, &Y, &Z) -> Result<H, String>, solver: impl SecondOrderOptimization<F, J, H, Z>, time: &[Quantity<T>], initial_condition: (Y, Z), equality_constraint: impl FnMut(Quantity<T>) -> EqualityConstraint, sparse: Option<SparseSolver>, ) -> Result<(Times<T>, U, W, V), IntegrationError>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, F, J, H, Y, Z, U, V, W, T> ExplicitDaeSecondOrderMinimize<F, J, H, Y, Z, U, V, W, T> for I
where Self: ExplicitDaeVariableStepExplicitSecondOrderMinimize<F, J, H, Y, Z, U, V, W, T>, Y: Differentiate<T> + Tensor, Z: PartialEq + Tensor, Derivative<Y, T>: Mul<Quantity<T>, Output = Y>, U: TensorVec<Item = Y>, V: TensorVec<Item = Z>, W: TensorVec<Item = Derivative<Y, T>>, for<'a> &'a Y: Mul<Scalar, Output = Y> + Sub<&'a Y, Output = Y>, for<'a> &'a Derivative<Y, T>: Mul<Scalar, Output = Derivative<Y, T>> + Mul<Quantity<T>, Output = Y>,