FreeInterpolant

Trait FreeInterpolant 

pub trait FreeInterpolant<Y, U>
where Self: VariableStepExplicit<Y, U>, Y: Tensor, for<'a> &'a Y: Mul<Scalar, Output = Y> + Sub<&'a Y, Output = Y>, U: TensorVec<Item = Y>,
{ // Provided method fn interpolate_free(time: &Vector, tp: &Vector, yp: &U, dydtp: &U) -> (U, U) { ... } }
Free (dense-output) interpolant for explicit ordinary differential equation integrators.

Uses cubic Hermite interpolation over the accepted-step values and derivatives already computed during integration, so it requires no additional evaluations of the right-hand side function.

Provided Methods

fn interpolate_free(time: &Vector, tp: &Vector, yp: &U, dydtp: &U) -> (U, U)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Y, U> FreeInterpolant<Y, U> for BogackiShampine
where Y: Tensor, for<'a> &'a Y: Mul<Scalar, Output = Y> + Sub<&'a Y, Output = Y>, U: TensorVec<Item = Y>,